TatweerAlertDialog class

Alert dialog component for displaying warnings and errors

Inheritance

Constructors

TatweerAlertDialog({Key? key, String? title, required String message, String type = 'warning', IconData? icon, String? buttonText, VoidCallback? onButtonPressed, Widget? contentWidget})
const

Properties

buttonText String?
Button text (defaults to "OK")
final
contentWidget Widget?
Custom content widget (overrides message if provided)
final
hashCode int
The hash code for this object.
no setterinherited
icon IconData?
Icon to display (auto-selected based on type if not provided)
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
message String
Dialog message/content
final
onButtonPressed VoidCallback?
Button callback
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
Dialog title
final
type String
Alert type: 'error', 'warning', or 'success'
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

show({required BuildContext context, String? title, required String message, String type = 'warning', IconData? icon, String? buttonText, VoidCallback? onButtonPressed, Widget? contentWidget}) Future<void>
Show the alert dialog