TatweerBaseDialog class

Base dialog component with consistent styling

Inheritance

Constructors

TatweerBaseDialog({Key? key, String? title, required Widget content, List<Widget>? actions, bool showCloseButton = true, Widget? titleWidget, EdgeInsetsGeometry? contentPadding, double? width, double? maxWidth, double? borderRadius, Color? backgroundColor})
const

Properties

actions List<Widget>?
List of action buttons
final
backgroundColor Color?
Background color
final
borderRadius double?
Border radius
final
content Widget
Dialog content widget
final
contentPadding EdgeInsetsGeometry?
Custom content padding
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxWidth double?
Dialog max width
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showCloseButton bool
Whether to show close button
final
title String?
Dialog title
final
titleWidget Widget?
Custom title widget (overrides title if provided)
final
width double?
Dialog width
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

show<T>({required BuildContext context, String? title, required Widget content, List<Widget>? actions, bool showCloseButton = true, Widget? titleWidget, EdgeInsetsGeometry? contentPadding, double? width, double? maxWidth, double? borderRadius, Color? backgroundColor, bool barrierDismissible = true}) Future<T?>
Show the dialog