TatweerConfirmationDialog class

Confirmation dialog component for user confirmations

Inheritance

Constructors

TatweerConfirmationDialog({Key? key, String? title, required String message, IconData? icon, Color? iconColor, String? confirmText, String? cancelText, VoidCallback? onConfirm, VoidCallback? onCancel, Color? confirmButtonColor, Widget? contentWidget})
const

Properties

cancelText String?
Cancel button text (defaults to "Cancel")
final
confirmButtonColor Color?
Confirm button color (defaults to primary)
final
confirmText String?
Confirm button text (defaults to "Confirm")
final
contentWidget Widget?
Custom content widget (overrides message if provided)
final
hashCode int
The hash code for this object.
no setterinherited
icon IconData?
Icon to display (defaults to question icon)
final
iconColor Color?
Icon color (defaults to warning color)
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
message String
Dialog message/content
final
onCancel VoidCallback?
Cancel button callback
final
onConfirm VoidCallback?
Confirm button callback
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
Dialog title
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

show({required BuildContext context, String? title, required String message, IconData? icon, Color? iconColor, String? confirmText, String? cancelText, VoidCallback? onConfirm, VoidCallback? onCancel, Color? confirmButtonColor, Widget? contentWidget}) Future<bool?>
Show the confirmation dialog and return the result