TatweerTextField class
Custom text field component with Tatweer styling
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- TatweerTextField
Constructors
-
TatweerTextField({Key? key, TextEditingController? controller, String? initialValue, String? hintText, String? label, String? helperText, String? errorText, bool enabled = true, bool readOnly = false, bool obscureText = false, TextInputType? keyboardType, int? maxLines = 1, int? minLines, int? maxLength, IconData? prefixIcon, IconData? suffixIcon, VoidCallback? onSuffixIconTap, ValueChanged<
String> ? onChanged, ValueChanged<String> ? onSubmitted, String? validator(String?)?, List<TextInputFormatter> ? inputFormatters, double? borderRadius, Color? borderColor, FocusNode? focusNode, TextCapitalization textCapitalization = TextCapitalization.none, bool autofocus = false}) -
const
Properties
- autofocus → bool
-
Autofocus
final
- borderColor → Color?
-
Border color
final
- borderRadius → double?
-
Border radius
final
- controller → TextEditingController?
-
Controller for the text field
final
- enabled → bool
-
Whether field is enabled
final
- errorText → String?
-
Error text
final
- focusNode → FocusNode?
-
Focus node
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- helperText → String?
-
Helper text shown below the field
final
- hintText → String?
-
Hint text
final
- initialValue → String?
-
Initial value
final
-
inputFormatters
→ List<
TextInputFormatter> ? -
Input formatters
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- keyboardType → TextInputType?
-
Text input type
final
- label → String?
-
Label text
final
- maxLength → int?
-
Maximum length
final
- maxLines → int?
-
Maximum number of lines
final
- minLines → int?
-
Minimum number of lines
final
- obscureText → bool
-
Whether to obscure text (for passwords)
final
-
onChanged
→ ValueChanged<
String> ? -
Callback when text changes
final
-
onSubmitted
→ ValueChanged<
String> ? -
Callback when field is submitted
final
- onSuffixIconTap → VoidCallback?
-
Callback when suffix icon is tapped
final
- prefixIcon → IconData?
-
Prefix icon
final
- readOnly → bool
-
Whether field is read-only
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- suffixIcon → IconData?
-
Suffix icon
final
- textCapitalization → TextCapitalization
-
Text capitalization
final
- validator → String? Function(String?)?
-
Validator function
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited